<?php

namespace Asadi\Faculty\Http\Controllers\Api;

use App\Http\Controllers\Api\PublicController as BaseController;
use Asadi\Faculty\Interfaces\FacultyRepositoryInterface;
use Asadi\Faculty\Repositories\Presenter\FacultyItemTransformer;

/**
 * Pubic API controller class.
 */
class FacultyPublicController extends BaseController
{
    /**
     * Constructor.
     *
     * @param type \Asadi\Faculty\Interfaces\FacultyRepositoryInterface $faculty
     *
     * @return type
     */
    public function __construct(FacultyRepositoryInterface $faculty)
    {
        $this->repository = $faculty;
        parent::__construct();
    }

    /**
     * Show faculty's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $faculties = $this->repository
            ->setPresenter('\\Asadi\\Faculty\\Repositories\\Presenter\\FacultyListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->paginate();

        $faculties['code'] = 2000;
        return response()->json($faculties)
                ->setStatusCode(200, 'INDEX_SUCCESS');
    }

    /**
     * Show faculty.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $faculty = $this->repository
            ->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        if (!is_null($faculty)) {
            $faculty         = $this->itemPresenter($module, new FacultyItemTransformer);
            $faculty['code'] = 2001;
            return response()->json($faculty)
                ->setStatusCode(200, 'SHOW_SUCCESS');
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }

    }
}
