<?php

namespace Asadi\Faculty\Http\Controllers;
use Litepie\Faculty\Http\Requests\FacultyRequest;
use Litepie\Faculty\Models\Faculty;

trait FacultyWorkflow {
	
    /**
     * Workflow controller function for faculty.
     *
     * @param Model   $faculty
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(FacultyRequest $request, Faculty $faculty, $step)
    {

        try {

            $faculty->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('faculty::faculty.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/faculty/faculty/' . $faculty->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/faculty/faculty/' . $faculty->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for faculty.
     *
     * @param Model   $faculty
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
    */

    public function getWorkflow(Faculty $faculty, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $faculty->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('faculty::faculty.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('faculty::admin.faculty.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('faculty::admin.faculty.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage(). '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('faculty::admin.faculty.message', $data)->render();

        }

    }
}