<?php

namespace Asadi\Faculty\Policies;

use App\User;
use Asadi\Faculty\Models\Faculty;

class FacultyPolicy
{

    /**
     * Determine if the given user can view the faculty.
     *
     * @param User $user
     * @param Faculty $faculty
     *
     * @return bool
     */
    public function view(User $user, Faculty $faculty)
    {
        if ($user->canDo('faculty.faculty.view') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.view') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $faculty->user_id;
    }

    /**
     * Determine if the given user can create a faculty.
     *
     * @param User $user
     * @param Faculty $faculty
     *
     * @return bool
     */
    public function create(User $user)
    {
        return  $user->canDo('faculty.faculty.create');
    }

    /**
     * Determine if the given user can update the given faculty.
     *
     * @param User $user
     * @param Faculty $faculty
     *
     * @return bool
     */
    public function update(User $user, Faculty $faculty)
    {
        if ($user->canDo('faculty.faculty.update') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.update') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $faculty->user_id;
    }

    /**
     * Determine if the given user can delete the given faculty.
     *
     * @param User $user
     * @param Faculty $faculty
     *
     * @return bool
     */
    public function destroy(User $user, Faculty $faculty)
    {
        if ($user->canDo('faculty.faculty.delete') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.delete') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $faculty->user_id;
    }

    /**
     * Determine if the given user can verify the given faculty.
     *
     * @param User $user
     * @param Faculty $faculty
     *
     * @return bool
     */
    public function verify(User $user, Faculty $faculty)
    {
        if ($user->canDo('faculty.faculty.verify') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('faculty.faculty.verify') 
        && $user->is('manager')
        && $faculty->user->parent_id == $user->id) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given faculty.
     *
     * @param User $user
     * @param Faculty $faculty
     *
     * @return bool
     */
    public function approve(User $user, Faculty $faculty)
    {
        if ($user->canDo('faculty.faculty.approve') && $user->is('admin')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperUser()) {
            return true;
        }
    }
}
