<?php

namespace Asadi\Faculty\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Asadi\Faculty\Models\Faculty;

class FacultyAction
{
    /**
     * Perform the complete action.
     *
     * @param Faculty $faculty
     *
     * @return Faculty
     */
    public function complete(Faculty $faculty)
    {
        try {
            $faculty->status = 'complete';
            return $faculty->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param Faculty $faculty
     *
     * @return Faculty
     */public function verify(Faculty $faculty)
    {
        try {
            $faculty->status = 'verify';
            return $faculty->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param Faculty $faculty
     *
     * @return Faculty
     */public function approve(Faculty $faculty)
    {
        try {
            $faculty->status = 'approve';
            return $faculty->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param Faculty $faculty
     *
     * @return Faculty
     */public function publish(Faculty $faculty)
    {
        try {
            $faculty->status = 'publish';
            return $faculty->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param Faculty $faculty
     *
     * @return Faculty
     */
    public function archive(Faculty $faculty)
    {
        try {
            $faculty->status = 'archive';
            return $faculty->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param Faculty $faculty
     *
     * @return Faculty
     */
    public function unpublish(Faculty $faculty)
    {
        try {
            $faculty->status = 'unpublish';
            return $faculty->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
